@@ -4,7 +4,7 @@ import datetime
 
 from pyboleto.bank.bradesco import BoletoBradesco
 
-from testutils import BoletoTestCase
+from .testutils import BoletoTestCase
 
 
 class TestBancoBradesco(BoletoTestCase):
@@ -21,9 +21,6 @@ class TestBancoBradesco(BoletoTestCase):
         d.numero_documento = '2125525'
         self.dados = d
 
-    def test_render(self):
-        self.check_pdf_rendering('bradesco', self.dados)
-
     def test_linha_digitavel(self):
         self.assertEqual(self.dados.linha_digitavel,
             '23790.27804 60000.212559 25003.923205 4 48690000828000'
